@@ -5,6 +5,9 @@
 
     :license: MIT, see LICENSE for more details.
 """
+import configparser
+import os
+
 import importlib
 from json.decoder import JSONDecodeError
 
@@ -16,6 +19,7 @@ from rich.syntax import Syntax
 import SoftLayer
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import routes
+from SoftLayer import utils
 
 # pylint: disable=too-many-instance-attributes, invalid-name
 
@@ -35,7 +39,8 @@ class Environment(object):
         self.vars = {}
 
         self.client = None
-        self.console = Console()
+        self.theme = self.set_env_theme()
+        self.console = utils.console_color_themes(self.theme)
         self.err_console = Console(stderr=True)
         self.format = 'table'
         self.skip_confirmations = False
@@ -76,7 +81,7 @@ class Environment(object):
         """Format output based on current the environment format."""
         if fmt is None:
             fmt = self.format
-        return formatting.format_output(output, fmt)
+        return formatting.format_output(output, fmt, self.theme)
 
     def format_output_is_json(self):
         """Return True if format output is json or jsonraw"""
@@ -208,6 +213,25 @@ class Environment(object):
             )
         self.client = client
 
+    def set_env_theme(self, config_file=None):
+        """Get theme to color console and set in env"""
+        theme = os.environ.get('SL_THEME')
+        if theme:
+            return theme
+        else:
+            config_files = ['/etc/softlayer.conf', '~/.softlayer']
+            path_os = os.getenv('HOME')
+            if path_os:
+                config_files.append(path_os + '\\AppData\\Roaming\\softlayer')
+            if config_file:
+                config_files.append(config_file)
+            config = configparser.RawConfigParser({'theme': 'dark'})
+            config.read(config_files)
+            if config.has_section('softlayer'):
+                self.theme = config.get('softlayer', 'theme')
+                return config.get('softlayer', 'theme')
+        return 'dark'
+
 
 class ModuleLoader(object):
     """Module loader that acts a little like an EntryPoint object."""
